/* GNOME DB libary
 * Copyright (C) 1998,1999 Michael Lausch
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __GDA_MYSQL_COMMAND_H__
#define __GDA_MYSQL_COMMAND_H__

#include "gda.h"
#include "gda-mysql-types.h"

Gda_MYSQL_Command*    gda_mysql_cmd_new            (void);
void                  gda_mysql_cmd_free           (Gda_MYSQL_Command* cmd);
Gda_MYSQL_Connection* gda_mysql_cmd_set_connection (Gda_MYSQL_Command* cmd, Gda_MYSQL_Connection* cnc);
Gda_MYSQL_Recordset*  gda_mysql_cmd_execute        (Gda_MYSQL_Command* cmd, const GDA_CmdParameterSeq* params, gulong options);

#endif
